
# q-expansion of newform 50.11.c.c, downloaded from the LMFDB on 10 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K.gens()[0]**i for i in range(len(poly_data))]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 50
weight = 11
poly_data = [1, 0, 1]

# The basis for the coefficient ring is just the power basis
# in the root of the defining polynomial above.
hecke_ring_character_values = [[27, [0, 1]]]
aps_data = [[-16, -16], [183, -183], [0, 0], [8407, 8407], [-173398, 0], [232623, -232623], [-1880033, -1880033], [0, -1101560], [5228263, -5228263], [0, -24790840], [-10065998, 0], [-56387913, -56387913], [-153003598, 0], [-59372457, 59372457], [-172339353, -172339353], [-196385617, 196385617], [0, 694068920], [906185802, 0], [962073967, 962073967], [-3120877598, 0], [636339263, -636339263], [0, -1967996640], [5183822103, -5183822103], [0, 7771383280], [640361247, 640361247], [2024343802, 0], [1502524583, -1502524583], [-1418116193, -1418116193], [0, -6212959480], [17951089823, -17951089823], [-13062106073, -13062106073], [-52022190598, 0], [16381452687, 16381452687], [0, -26148958120], [0, 4313626200], [113868406402, 0], [-10442780793, -10442780793], [-47830549577, 47830549577], [11828130167, 11828130167], [116377366063, -116377366063], [0, -181010928440], [133000325402, 0], [131043806002, 0], [-212792488257, 212792488257], [-79024621353, -79024621353], [0, 452657290800], [137994639002, 0], [126053692263, -126053692263], [-115268207473, -115268207473], [0, -329124036840], [99794809503, -99794809503], [0, -39562237920], [-814270609598, 0], [453171013002, 0], [-1335788872993, -1335788872993], [912065175623, -912065175623], [0, 1043476578440], [719444957202, 0], [862576489527, 862576489527], [-789299999598, 0], [660245134903, -660245134903], [-179236397457, 179236397457], [1101553373007, 1101553373007], [5311384908802, 0], [840078380223, -840078380223], [1166347782567, 1166347782567], [-4820422072598, 0], [3685497774687, 3685497774687], [5384498447647, 5384498447647], [0, 8126579105800], [-5492737385217, 5492737385217], [0, -5913045067280], [-1753598840633, -1753598840633], [-4257172389937, 4257172389937], [0, -7209991060040], [6938318326503, -6938318326503], [0, 11251772045880], [7946276374247, 7946276374247], [8810722856802, 0], [0, -10016009696880], [0, 14824395641640], [-4685003428198, 0], [23912644242002, 0], [741822675103, -741822675103], [0, 20970445584080], [23890926418743, -23890926418743], [0, -20453537970400], [-6885206622993, -6885206622993], [-17203850090998, 0], [467191847623, -467191847623], [-16276805236433, -16276805236433], [0, -32675924919040], [-3916166452713, -3916166452713], [-1669454762198, 0], [0, 26911278389000], [-23550122149017, 23550122149017], [0, -8636213892280], [-62732628945198, 0], [-1489512083337, 1489512083337], [-89711512202198, 0], [-33995478931953, -33995478931953], [-9519145028793, -9519145028793], [-36365147631177, 36365147631177], [0, -28285933224560], [2192009421002, 0], [29757859348127, 29757859348127], [-46033254317313, -46033254317313], [6177137322943, -6177137322943], [0, -58030996850800], [124750357414802, 0], [93418378294407, 93418378294407], [-14280173155377, 14280173155377], [4177403266767, 4177403266767], [0, 40797747527640], [80355572220802, 0], [94347712104802, 0], [-19892461882857, 19892461882857], [-59728871309353, -59728871309353], [98707248211983, -98707248211983], [0, 58068882437320], [-153137463592198, 0], [87535971111263, -87535971111263], [-1594524311273, -1594524311273], [56579574527703, -56579574527703], [4985576867802, 0], [-180303257628598, 0], [0, -311542786085480], [0, -165068133312160], [-215313966939273, -215313966939273], [278786616982703, -278786616982703], [0, -205170755975320], [-159047209676857, 159047209676857], [-140007869581998, 0], [-70788089995593, -70788089995593], [-284952799093198, 0], [0, -359991010845760], [-140031716617137, 140031716617137], [-299888126528113, -299888126528113], [214433006126247, 214433006126247], [0, 371569006907920], [425888727868202, 0], [473944086862202, 0], [393378088647463, -393378088647463], [232821673186527, 232821673186527], [0, -97333684556440], [0, 382848375860080], [-425917526760817, 425917526760817], [358496526204207, 358496526204207], [0, -730888426844680], [-148513147065977, 148513147065977], [38560860981927, 38560860981927], [-411263967729598, 0], [634115560920503, -634115560920503], [-715240745272713, -715240745272713], [-462742823901793, -462742823901793], [-241311535745198, 0], [0, -374681845717360], [0, 447350621276960], [234215056777487, 234215056777487], [-38052568047798, 0], [-12656670587953, -12656670587953], [773543568285183, -773543568285183], [557903577968567, 557903577968567], [101087413375402, 0], [713366306105727, 713366306105727], [514730602885703, -514730602885703], [1133562513594802, 0], [-655684564697353, -655684564697353]]
